{% extends "base.html" %}{% comment %} -*- mode: django-html; tab-width: 4 -*- {% endcomment %}

{% block content %}
<div id="content">
  <div id="disclaimer">
Disclaimer:  All reference to Planning Districts on any maps or digital
data produced by the Office of Digital Cartography and GIS, Planning
Department, BRA are for planning purposes only and should NOT be
interpreted as official neighborhood boundaries for the City of
Boston. Thank you.
  </div>
</div><!--/ #content -->
{% endblock %}
