{% extends "ebpub/templates/db/place_detail.html" %}

{% block extracontent %}
{% ifequal place.location_type.slug "neighborhoods" %}
<div id="disclaimer"> Disclaimer: All reference to Planning Districts
on any maps or digital data produced by the Office of Digital
Cartography and GIS, Planning Department, BRA are for planning
purposes only and should NOT be interpreted as official neighborhood
boundaries for the City of Boston. Thank you.
</div>
{% endifequal %}
{% endblock %}